# Source Generated with Decompyle++
# File: in.pyc (Python 1.5)

error = 'Registry Setup Error'
import sys

def FileExists(fname):
    '''Check if a file exists.  Returns true or false.
\t'''
    import os
    
    try:
        os.stat(fname)
        return 1
    except os.error:
        details = None
        return 0



def IsPackageDir(path, packageName, knownFileName):
    '''Given a path, a ni package name, and possibly a known file name in
           the root of the package, see if this path is good.
      '''
    import os
    if knownFileName is None:
        knownFileName = '.'
    
    return FileExists(os.path.join(os.path.join(path, packageName), knownFileName))


def FindPackagePath(packageName, knownFileName, searchPaths):
    '''Find a package.

           Given a ni style package name, check the package is registered.

           First place looked is the registry for an existing entry.  Then
           the searchPaths are searched.
      '''
    import win32api
    import win32con
    import regutil
    pathLook = regutil.GetRegisteredNamedPath(packageName)
    if pathLook and IsPackageDir(pathLook, packageName, knownFileName):
        return (pathLook, None)
    
    for pathLook in searchPaths:
        pass
    
    raise error, 'The package %s can not be located' % packageName


def FindHelpPath(helpFile, helpDesc, searchPaths):
    import win32api
    import win32con
    import os
    
    try:
        key = win32api.RegOpenKey(win32con.HKEY_LOCAL_MACHINE, 'Software\\Microsoft\\Windows\\Help', 0, win32con.KEY_ALL_ACCESS)
        
        try:
            
            try:
                path = win32api.RegQueryValueEx(key, helpDesc)[0]
                print 'Looking in', path
                if FileExists(os.path.join(path, helpFile)):
                    return win32api.GetFullPathName(path)
            except win32api.error:
                pass

        finally:
            win32api.RegCloseKey(key)

    except win32api.error:
        pass

    for pathLook in searchPaths:
        pathLook = os.path.join(pathLook, 'Help')
        if FileExists(os.path.join(pathLook, helpFile)):
            return win32api.GetFullPathName(pathLook)
        
    
    raise error, 'The help file %s can not be located' % helpFile


def FindAppPath(appName, knownFileName, searchPaths):
    '''Find an application.

         First place looked is the registry for an existing entry.  Then
         the searchPaths are searched.
      '''
    import win32api
    import win32con
    import regutil
    import string
    import os
    regPath = regutil.GetRegisteredNamedPath(appName)
    if regPath:
        pathLook = string.split(regPath, ';')[0]
    
    if regPath and FileExists(os.path.join(pathLook, knownFileName)):
        return None
    
    for pathLook in searchPaths:
        pass
    
    raise error, 'The file %s can not be located for application %s' % (knownFileName, appName)


def FindRegisteredModule(moduleName, possibleRealNames, searchPaths):
    '''Find a registered module.

         First place looked is the registry for an existing entry.  Then
         the searchPaths are searched.
         
\t   Returns the full path to the .exe or None if the current registered entry is OK.
      '''
    import win32api
    import win32con
    import regutil
    import string
    
    try:
        fname = win32api.RegQueryValue(regutil.GetRootKey(), regutil.BuildDefaultPythonKey() + '\\Modules\\%s' % moduleName)
        if FileExists(fname):
            return None
    except win32api.error:
        pass

    return LocateFileName(possibleRealNames, searchPaths)


def FindPythonExe(exeAlias, possibleRealNames, searchPaths):
    '''Find an exe.

         First place looked is the registry for an existing entry.  Then
         the searchPaths are searched.
         
\t   Returns the full path to the .exe, and a boolean indicating if the current 
\t   registered entry is OK.
      '''
    import win32api
    import win32con
    import regutil
    import string
    if possibleRealNames is None:
        possibleRealNames = exeAlias
    
    
    try:
        fname = win32api.RegQueryValue(regutil.GetRootKey(), regutil.GetAppPathsKey() + '\\' + exeAlias)
        if FileExists(fname):
            return (fname, 1)
    except win32api.error:
        pass

    return (LocateFileName(possibleRealNames, searchPaths), 0)


def QuotedFileName(fname):
    '''Given a filename, return a quoted version if necessary
      '''
    import win32api
    import win32con
    import regutil
    import string
    
    try:
        string.index(fname, ' ')
        return '"%s"' % fname
    except ValueError:
        return fname



def LocateFileName(fileNamesString, searchPaths):
    '''Locate a file name, anywhere on the search path.

\t   If the file can not be located, prompt the user to find it for us
\t   (using a common OpenFile dialog)

\t   Raises KeyboardInterrupt if the user cancels.
\t'''
    import win32api
    import win32con
    import regutil
    import string
    import os
    fileNames = string.split(fileNamesString, ';')
    for path in searchPaths:
        for fileName in fileNames:
            
            try:
                retPath = os.path.join(path, fileName)
                os.stat(retPath)
            except os.error:
                0
                0
                fileNames
                retPath = None
            except:
                0

        
    else:
        fileName = fileNames[0]
        
        try:
            import win32ui
        except ImportError:
            None if retPath else searchPaths
            None if retPath else searchPaths
            raise error, 'Need to locate the file %s, but the win32ui module is not available\nPlease run the program again, passing as a parameter the path to this file.' % fileName
        except:
            None if retPath else searchPaths

        flags = win32con.OFN_FILEMUSTEXIST
        ext = os.path.splitext(fileName)[1]
        filter = 'Files of requested type (*%s)|*%s||' % (ext, ext)
        dlg = win32ui.CreateFileDialog(1, None, fileName, flags, filter, None)
        if dlg.DoModal() != win32con.IDOK:
            raise KeyboardInterrupt, 'User cancelled the process'
        
        retPath = dlg.GetPathName()
    return win32api.GetFullPathName(retPath)


def LocatePath(fileName, searchPaths):
    '''Like LocateFileName, but returns a directory only.
\t'''
    import os
    import win32api
    return win32api.GetFullPathName(os.path.split(LocateFileName(fileName, searchPaths))[0])


def LocateOptionalPath(fileName, searchPaths):
    '''Like LocatePath, but returns None if the user cancels.
\t'''
    
    try:
        return LocatePath(fileName, searchPaths)
    except KeyboardInterrupt:
        return None



def LocateOptionalFileName(fileName, searchPaths = None):
    '''Like LocateFileName, but returns None if the user cancels.
\t'''
    
    try:
        return LocateFileName(fileName, searchPaths)
    except KeyboardInterrupt:
        return None



def LocatePythonCore(searchPaths):
    '''Locate and validate the core Python directories.  Returns a list
         of paths that should be used as the core (ie, un-named) portion of
         the Python path.
\t'''
    import win32api
    import win32con
    import string
    import os
    import regutil
    currentPath = regutil.GetRegisteredNamedPath(None)
    if currentPath:
        presearchPaths = string.split(currentPath, ';')
    else:
        presearchPaths = [
            win32api.GetFullPathName('.')]
    libPath = None
    for path in presearchPaths:
        pass
    
    if libPath is None and searchPaths is not None:
        libPath = LocatePath('os.py', searchPaths)
    
    if libPath is None:
        raise error, 'The core Python library could not be located.'
    
    corePath = None
    for path in presearchPaths:
        pass
    
    if corePath is None and searchPaths is not None:
        corePath = LocatePath('parser.dll', searchPaths)
    
    if corePath is None:
        raise error, 'The core Python path could not be located.'
    
    installPath = win32api.GetFullPathName(os.path.join(libPath, '..'))
    return (installPath, [
        libPath,
        corePath])


def FindRegisterPackage(packageName, knownFile, searchPaths):
    '''Find and Register a package.

\t   Assumes the core registry setup correctly.

\t   In addition, if the location located by the package is already
           in the **core** path, then an entry is registered, but no path.
\t   (no other paths are checked, as the application whose path was used
\t   may later be uninstalled.  This should not happen with the core)
\t'''
    import win32api
    import win32con
    import regutil
    import string
    if not packageName:
        raise error, 'A package name must be supplied'
    
    corePaths = string.split(regutil.GetRegisteredNamedPath(None), ';')
    if not searchPaths:
        searchPaths = corePaths
    
    
    try:
        (pathLook, pathAdd) = FindPackagePath(packageName, knownFile, searchPaths)
        if pathAdd is not None:
            if pathAdd in corePaths:
                pathAdd = ''
            
            regutil.RegisterNamedPath(packageName, pathAdd)
        
        return pathLook
    except error:
        details = None
        print '*** The %s package could not be registered - %s' % (packageName, details)
        print '*** Please ensure you have passed the correct paths on the command line.'
        print '*** - For packages, you should pass a path to the packages parent directory,'
        print '*** - and not the package directory itself...'



def FindRegisterApp(appName, knownFiles, searchPaths):
    '''Find and Register a package.

\t   Assumes the core registry setup correctly.

\t'''
    import win32api
    import win32con
    import regutil
    import string
    if type(knownFiles) == type(''):
        knownFiles = [
            knownFiles]
    
    paths = []
    
    try:
        for knownFile in knownFiles:
            pathLook = FindAppPath(appName, knownFile, searchPaths)
    except error:
        details = None
        print '*** ', details
        return None

    regutil.RegisterNamedPath(appName, string.join(paths, ';'))


def FindRegisterModule(modName, actualFileNames, searchPaths):
    '''Find and Register a module.

\t   Assumes the core registry setup correctly.
\t'''
    import regutil
    
    try:
        fname = FindRegisteredModule(modName, actualFileNames, searchPaths)
        if fname is not None:
            regutil.RegisterModule(modName, fname)
    except error:
        details = None
        print '*** ', details



def FindRegisterPythonExe(exeAlias, searchPaths, actualFileNames = None):
    '''Find and Register a Python exe (not necessarily *the* python.exe)

\t   Assumes the core registry setup correctly.
\t'''
    import win32api
    import win32con
    import regutil
    import string
    (fname, ok) = FindPythonExe(exeAlias, actualFileNames, searchPaths)
    if not ok:
        regutil.RegisterPythonExe(fname, exeAlias)
    
    return fname


def FindRegisterHelpFile(helpFile, searchPaths, helpDesc = None):
    import regutil
    
    try:
        pathLook = FindHelpPath(helpFile, helpDesc, searchPaths)
    except error:
        details = None
        print '*** ', details
        return None

    regutil.RegisterHelpFile(helpFile, pathLook, helpDesc)


def SetupCore(searchPaths):
    '''Setup the core Python information in the registry.

\t   This function makes no assumptions about the current state of sys.path.

\t   After this function has completed, you should have access to the standard
\t   Python library, and the standard Win32 extensions
\t'''
    import sys
    for path in searchPaths:
        sys.path.append(path)
    
    import string
    import os
    import regutil
    import win32api
    import win32con
    (installPath, corePaths) = LocatePythonCore(searchPaths)
    print corePaths
    regutil.RegisterNamedPath(None, string.join(corePaths, ';'))
    hKey = win32api.RegCreateKey(regutil.GetRootKey(), regutil.BuildDefaultPythonKey())
    
    try:
        win32api.RegSetValue(hKey, 'InstallPath', win32con.REG_SZ, installPath)
    finally:
        win32api.RegCloseKey(hKey)

    regutil.RegisterCoreDLL()
    win32paths = win32api.GetFullPathName(os.path.split(win32api.__file__)[0]) + ';' + win32api.GetFullPathName(os.path.split(LocateFileName('win32con.py;win32con.pyc', sys.path))[0])
    FindRegisterModule('pywintypes', 'pywintypes15.dll', [
        '.',
        win32api.GetSystemDirectory()])
    regutil.RegisterNamedPath('win32', win32paths)


def RegisterShellInfo(searchPaths):
    '''Registers key parts of the Python installation with the Windows Shell.

\t   Assumes a valid, minimal Python installation exists
\t   (ie, SetupCore() has been previously successfully run)
\t'''
    import regutil
    import win32con
    exePath = FindRegisterPythonExe('Python.exe', searchPaths)
    regutil.SetRegistryDefaultValue('.py', 'Python.File', win32con.HKEY_CLASSES_ROOT)
    regutil.RegisterShellCommand('Open', QuotedFileName(exePath) + ' %1 %*', '&Run')
    regutil.SetRegistryDefaultValue('Python.File\\DefaultIcon', '%s,0' % exePath, win32con.HKEY_CLASSES_ROOT)
    FindRegisterHelpFile('Python.hlp', searchPaths, 'Main Python Documentation')


def RegisterPythonwin(searchPaths):
    '''Knows how to register Pythonwin components
\t'''
    import regutil
    FindRegisterApp('Pythonwin', 'docview.py', searchPaths)
    FindRegisterHelpFile('Pythonwin.hlp', searchPaths, 'Pythonwin Reference')
    FindRegisterPythonExe('pythonwin.exe', searchPaths, 'Pythonwin.exe')
    regutil.RegisterShellCommand('Edit', QuotedFileName('pythonwin.exe') + ' /edit %1')
    regutil.RegisterDDECommand('Edit', 'Pythonwin', 'System', '[self.OpenDocumentFile(r"%1")]')
    FindRegisterModule('win32ui', 'win32ui.pyd', searchPaths)
    FindRegisterModule('win32uiole', 'win32uiole.pyd', searchPaths)
    fnamePythonwin = regutil.GetRegisteredExe('Pythonwin.exe')
    fnamePython = regutil.GetRegisteredExe('Python.exe')
    regutil.RegisterFileExtensions(defPyIcon = fnamePythonwin + ',0', defPycIcon = fnamePythonwin + ',5', runCommand = QuotedFileName(fnamePython) + ' %1 %*')


def UnregisterPythonwin():
    '''Knows how to unregister Pythonwin components
\t'''
    import regutil
    regutil.UnregisterNamedPath('Pythonwin')
    regutil.UnregisterHelpFile('Pythonwin.hlp')
    regutil.UnregisterPythonExe('pythonwin.exe')
    regutil.UnregisterModule('win32ui')
    regutil.UnregisterModule('win32uiole')


def RegisterWin32com(searchPaths):
    '''Knows how to register win32com components
\t'''
    import win32api
    corePath = FindRegisterPackage('win32com', 'olectl.py', searchPaths)
    if corePath:
        FindRegisterHelpFile('win32com.hlp', searchPaths + [
            corePath + '\\win32com'], 'Python COM Reference')
        FindRegisterModule('pythoncom', 'pythoncom15.dll', [
            win32api.GetSystemDirectory(),
            '.'])
    

usage = 'regsetup.py - Setup/maintain the registry for Python apps.\n\nRun without options, (but possibly search paths) to repair a totally broken\npython registry setup.  This should allow other options to work.\n\nUsage:   %s [options ...] paths ...\n-p packageName  -- Find and register a package.  Looks in the paths for\n                   a sub-directory with the name of the package, and\n                   adds a path entry for the package.\n-a appName      -- Unconditionally add an application name to the path.\n                   A new path entry is create with the app name, and the\n                   paths specified are added to the registry.\n-c              -- Add the specified paths to the core Pythonpath.\n                   If a path appears on the core path, and a package also \n                   needs that same path, the package will not bother \n                   registering it.  Therefore, By adding paths to the \n                   core path, you can avoid packages re-registering the same path.  \n-m filename     -- Find and register the specific file name as a module.\n                   Do not include a path on the filename!\n--shell         -- Register everything with the Win95/NT shell.\n--pythonwin     -- Find and register all Pythonwin components.\n--unpythonwin   -- Unregister Pythonwin\n--win32com      -- Find and register all win32com components\n--upackage name -- Unregister the package\n--uapp name     -- Unregister the app (identical to --upackage)\n--umodule name  -- Unregister the module\n\n--description   -- Print a description of the usage.\n--examples      -- Print examples of usage.\n' % sys.argv[0]
description = 'If no options are processed, the program attempts to validate and set \nthe standard Python path to the point where the standard library is\navailable.  This can be handy if you move Python to a new drive/sub-directory,\nin which case most of the options would fail (as they need at least string.py,\nos.py etc to function.)\nRunning without options should repair Python well enough to run with \nthe other options.\n\npaths are search paths that the program will use to seek out a file.\nFor example, when registering the core Python, you may wish to\nprovide paths to non-standard places to look for the Python help files,\nlibrary files, etc.  When registering win32com, you should pass paths\nspecific to win32com.\n\nSee also the "regcheck.py" utility which will check and dump the contents\nof the registry.\n'
examples = 'Examples:\n"regsetup c:\\wierd\\spot\\1 c:\\wierd\\spot\\2"\nAttempts to setup the core Python.  Looks in some standard places,\nas well as the 2 wierd spots to locate the core Python files (eg, Python.exe,\npython14.dll, the standard library and Win32 Extensions.\n\n"regsetup --win32com"\nAttempts to register win32com.  No options are passed, so this is only\nlikely to succeed if win32com is already successfully registered, or the\nwin32com directory is current.  If neither of these are true, you should pass\nthe path to the win32com directory.\n\n"regsetup -a myappname . .\\subdir"\nRegisters a new Pythonpath entry named myappname, with "C:\\I\\AM\\HERE" and\n"C:\\I\\AM\\HERE\\subdir" added to the path (ie, all args are converted to\nabsolute paths)\n\n"regsetup -c c:\\my\\python\\files"\nUnconditionally add "c:\\my\\python\\files" to the \'core\' Python path.\n\n"regsetup -m some.pyd \\windows\\system"\nRegister the module some.pyd in \\windows\\system as a registered\nmodule.  This will allow some.pyd to be imported, even though the\nwindows system directory is not (usually!) on the Python Path.\n\n"regsetup --umodule some"\nUnregister the module "some".  This means normal import rules then apply\nfor that module.\n'
if __name__ == '__main__':
    if len(sys.argv) > 1 and sys.argv[1] in [
        '/?',
        '-?',
        '-help',
        '-h']:
        print usage
    elif len(sys.argv) == 1 or not (sys.argv[1][0] in [
        '/',
        '-']):
        searchPath = sys.path[:]
        for arg in sys.argv[1:]:
            searchPath.append(arg)
        
        searchPath.append('..\\..')
        print 'Attempting to setup/repair the Python core'
        SetupCore(searchPath)
        RegisterShellInfo(searchPath)
        print 'Registration complete - checking the registry...'
        import regcheck
        regcheck.CheckRegistry()
    else:
        searchPaths = []
        import getopt
        import string
        (opts, args) = getopt.getopt(sys.argv[1:], 'p:a:m:c', [
            'pythonwin',
            'unpythonwin',
            'win32com',
            'shell',
            'upackage=',
            'uapp=',
            'umodule=',
            'description',
            'examples'])
        for arg in args:
            searchPaths.append(arg)
        
        for o, a in opts:
            pass
        

